@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -175,7 +175,7 @@ static void
 changed_align (GtkWidget *w, GtkHTMLEditImageProperties *d)
 {
 	if (!d->disable_change && editor_has_html_object (d->cd, HTML_OBJECT (d->image)))
-		html_image_set_valign (d->image, g_list_index (GTK_MENU_SHELL (w)->children, gtk_menu_get_active (GTK_MENU (w))));
+		html_image_set_valign (d->image, gtk_combo_box_get_active (GTK_COMBO_BOX (d->option_align)));
 }
 
 static void
@@ -276,7 +276,7 @@ image_set_ui (GtkHTMLEditImageProperties *d)
 
 			if (ip->url) {
 				gchar *filename = gtk_html_filename_from_uri (ip->url);
-				
+
 				gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (d->pentry), filename);
 				g_free (filename);
 			}
